@@ -5,6 +5,7 @@ from functools import partial
 from typing import Any, Dict, List, Optional, Set
 
 import pandas as pd
+from numpy import nan
 from AnyQt.QtCore import (
     QAbstractTableModel,
     QEvent,
@@ -58,7 +59,7 @@ AGGREGATIONS = {
     "Mean": Aggregation("mean", {ContinuousVariable, TimeVariable}),
     "Median": Aggregation("median", {ContinuousVariable, TimeVariable}),
     "Mode": Aggregation(
-        lambda x: pd.Series.mode(x)[0], {ContinuousVariable, TimeVariable}
+        lambda x: pd.Series.mode(x).get(0, nan), {ContinuousVariable, TimeVariable}
     ),
     "Standard deviation": Aggregation("std", {ContinuousVariable, TimeVariable}),
     "Variance": Aggregation("var", {ContinuousVariable, TimeVariable}),
@@ -404,7 +405,7 @@ class OWGroupBy(OWWidget, ConcurrentWidgetMixin):
         self.gb_attrs = [values[row.row()] for row in sorted(rows)]
         # everything cached in result should be recomputed on gb change
         self.result = Result()
-        self.commit()
+        self.commit.deferred()
 
     def __aggregation_changed(self, agg: str) -> None:
         """
@@ -420,7 +421,7 @@ class OWGroupBy(OWWidget, ConcurrentWidgetMixin):
             else:
                 self.aggregations[attr].discard(agg)
             self.agg_table_model.update_aggregation(attr)
-        self.commit()
+        self.commit.deferred()
 
     @Inputs.data
     def set_data(self, data: Table) -> None:
@@ -448,11 +449,12 @@ class OWGroupBy(OWWidget, ConcurrentWidgetMixin):
         self.agg_table_model.set_domain(data.domain if data else None)
         self._set_gb_selection()
 
-        self.commit()
+        self.commit.now()
 
     #########################
     # Task connected methods
 
+    @gui.deferred
     def commit(self) -> None:
         self.Error.clear()
         self.Warning.clear()
